Line

Struct Line 

#[repr(C)]
pub struct Line<T> { pub start: Vec2<T>, pub end: Vec2<T>, }
A line segment connecting two points.

Fields

start: Vec2<T>

The start point.

end: Vec2<T>

The end point.

Implementations

Source

impl<T: Pod + NoUninit> Line<T>

pub fn as_bytes(&self) -> &[u8]

This type re-interpreted as a slice of bytes.

pub fn as_bytes_mut(&mut self) -> &mut [u8]

This type re-interpreted as a mutable slice of bytes.

Source

impl<T: Copy + AbsDiffEq<Epsilon = T>> Line<T>

pub fn abs_diff_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components.

Source

impl<T: Copy + RelativeEq<Epsilon = T>> Line<T>

pub fn relative_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components, as well as relative-based comparisons.

Source

impl<T: Copy + UlpsEq<Epsilon = T>> Line<T>

pub fn ulps_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components, as well as ULPs (Units in Last Place).

Source

impl<T> Line<T>

pub const fn new(start: Vec2<T>, end: Vec2<T>) -> Self

Create a new line.

pub fn points(self) -> [Vec2<T>; 2]

The points of the line.

pub fn rev(self) -> Self

Reverse the line (swap the start and end points).

Source

impl<T: Num> Line<T>

pub const ZERO: Self

A line with both start and end at (0, 0).

pub fn vector(&self) -> Vec2<T>

The vector from the line’s start to end point.

pub fn sqr_len(&self) -> T

Squared length of the line.

pub fn bounds(&self) -> Rect<T>

Rectangular bounds of the line.

pub fn center_x(&self) -> T

X-position of the line’s center.

pub fn center_y(&self) -> T

Y-position of the line’s center.

pub fn center(&self) -> Vec2<T>

The line’s center.

Source

impl<T: Float> Line<T>

pub fn len(&self) -> T

Length of the line.

pub fn norm(&self) -> Vec2<T>

Axis of the line from a to b.

pub fn left_norm(&self) -> Vec2<T>

Left-perpendicular axis of the line.

pub fn right_norm(&self) -> Vec2<T>

Right-perpendicular axis of the line.

pub fn project_onto_axis(&self, axis: Vec2<T>) -> Projection<T>

Project this line onto the provided axis.

pub fn project_point(&self, p: Vec2<T>) -> Vec2<T>

Project the point onto this line.

pub fn rayhit(&self, ray: &Ray<T>) -> bool

Check if the ray hits this line.

pub fn raycast(&self, ray: &Ray<T>) -> Option<T>

Cast a ray against this line. If it intersects the line, return the distance along the ray that the intersection occurred.

pub fn transform_by(&self, f: impl FnMut(Vec2<T>) -> Vec2<T>) -> Self