Projection

Struct Projection 

#[repr(C)]
pub struct Projection<T> { pub min: T, pub max: T, }
Represents the projection of a 2D shape on an axis.

This primitive does not contain the axis itself, merely the start and end bounds of the projection. This is used in overlap checks for convex shapes.

Fields

min: Tmax: T

Implementations

Source

impl<T: Pod + NoUninit> Projection<T>

pub fn as_bytes(&self) -> &[u8]

This type re-interpreted as a slice of bytes.

pub fn as_bytes_mut(&mut self) -> &mut [u8]

This type re-interpreted as a mutable slice of bytes.

Source

impl<T: Copy + AbsDiffEq<Epsilon = T>> Projection<T>

pub fn abs_diff_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components.

Source

impl<T: Copy + RelativeEq<Epsilon = T>> Projection<T>

pub fn relative_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components, as well as relative-based comparisons.

Source

impl<T: Copy + UlpsEq<Epsilon = T>> Projection<T>

pub fn ulps_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components, as well as ULPs (Units in Last Place).

Source

impl<T> Projection<T>

pub const fn new(min: T, max: T) -> Self

Create a new projection.

Source

impl<T: Num> Projection<T>

pub const ZERO: Self

A projection of range [0, 0].

pub fn contains(&self, value: T) -> bool

pub fn overlaps(&self, other: Projection<T>) -> bool

Returns true if this projection overlaps the other.

pub fn overlap(&self, other: Projection<T>) -> Option<T>

If this projection overlaps the other, returns the amount which it overlaps.

pub fn len(&self) -> T

Length of the projection.

pub fn center(&self) -> T

Center of the projection.