RayHit

Struct RayHit 

#[repr(C)]
pub struct RayHit<T> { pub normal: Vec2<T>, pub distance: T, }
A raycast hit on the surface of a shape.

Contains the distance along the ray the hit occurred, and the normal of the edge the ray intersected.

Fields

normal: Vec2<T>distance: T

Implementations

Source

impl<T> RayHit<T>

pub const fn new(normal: Vec2<T>, distance: T) -> Self

Create a new raycast hit.

Source

impl<T: Pod + NoUninit> RayHit<T>

pub fn as_bytes(&self) -> &[u8]

This type re-interpreted as a slice of bytes.

pub fn as_bytes_mut(&mut self) -> &mut [u8]

This type re-interpreted as a mutable slice of bytes.

Source

impl<T: Copy + AbsDiffEq<Epsilon = T>> RayHit<T>

pub fn abs_diff_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components.

Source

impl<T: Copy + RelativeEq<Epsilon = T>> RayHit<T>

pub fn relative_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components, as well as relative-based comparisons.

Source

impl<T: Copy + UlpsEq<Epsilon = T>> RayHit<T>

pub fn ulps_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components, as well as ULPs (Units in Last Place).