Vec4

Struct Vec4 

#[repr(C)]
pub struct Vec4<T> { pub x: T, pub y: T, pub z: T, pub w: T, }
A 4-dimensional vector.

Fields

x: Ty: Tz: Tw: T

Implementations

Source

impl<T> Vec4<T>

pub const fn new(x: T, y: T, z: T, w: T) -> Self

Create a new vector.

pub fn map<U, F: FnMut(T) -> U>(self, f: F) -> Vec4<U>

Map the components of this vector.

pub fn splat(value: T) -> Self
where T: Copy,

Create a new vector with all components set to value.

pub fn abs(self) -> Self
where T: Signed,

Returns a copy of this vector with absolute value of all components.

pub fn signum(self) -> Self
where T: Signed,

Returns a copy of this vector with signed value of all components.

pub fn is_zero(self) -> bool
where T: Num,

Returns true if all components are set to zero.

pub fn min(self, rhs: Self) -> Self
where T: Num,

Returns a new value where each component is set to the smallest value of each of the supplied vector’s corresponding components.

pub fn max(self, rhs: Self) -> Self
where T: Num,

Returns a new value where each component is set to the greatest value of each of the supplied vector’s corresponding components.

pub fn clamp(self, min: Self, max: Self) -> Self
where T: Num,

Clamps the vector’s components within the provided bounds.

pub fn round(self) -> Self
where T: Float,

Rounds the components of this vector.

pub fn floor(self) -> Self
where T: Float,

Rounds down the components of this vector.

pub fn ceil(self) -> Self
where T: Float,

Rounds up the components of this vector.

pub fn trunc(self) -> Self
where T: Float,

Truncates the components of this vector. This means that non-integer numbers are always truncated towards zero.

pub fn dot(self, other: Self) -> T
where T: Num,

The dot product of this vector and another.

pub fn sqr_len(self) -> T
where T: Num,

The squared length of this vector.

pub fn sqr_dist(self, other: Self) -> T
where T: Num,

The square distance between this vector and another.

pub fn reflect(self, normal: Self) -> Self
where T: Num,

Reflects this vector off the provided normal.

pub fn len(&self) -> T
where T: Float,

The length of this vector.

pub fn dist(self, other: Self) -> T
where T: Float,

The distance between this vector and another.

pub fn norm(self) -> Self
where T: Float,

Returns a normalized version of this vector.

pub fn norm_safe(self) -> Self
where T: Float,

Returns a normalized version of this vector, or a zeroed vector if the vector cannot be normalized.

pub fn len_to(self, new_len: T) -> Self
where T: Float,

Returns a copy of this vector resized to be the provided length.

pub fn len_to_safe(self, new_len: T) -> Self
where T: Float,

Returns a copy of this vector resized to be the provided length, or a zeroed vector if the original could not be normalized.

pub fn dir_to(self, other: Self) -> Self
where T: Float,

Returns the normalized direction towards the other point.

Source

impl<T: Num> Vec4<T>

pub const ZERO: Self

pub const ONE: Self

pub const MIN: Self

pub const MAX: Self

Source

impl<T: Copy + AbsDiffEq<Epsilon = T>> Vec4<T>

pub fn abs_diff_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components.

Source

impl<T: Copy + RelativeEq<Epsilon = T>> Vec4<T>

pub fn relative_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components, as well as relative-based comparisons.

Source

impl<T: Copy + UlpsEq<Epsilon = T>> Vec4<T>

pub fn ulps_eq(&self, other: &Self) -> bool

Returns true if the two values are approximately equal according to the absolute difference between their components, as well as ULPs (Units in Last Place).

Source

impl<T: Pod + NoUninit> Vec4<T>

pub fn as_bytes(&self) -> &[u8]

This type re-interpreted as a slice of bytes.

pub fn as_bytes_mut(&mut self) -> &mut [u8]

This type re-interpreted as a mutable slice of bytes.

Source

impl<T> Vec4<T>

pub fn with_x(self, x: T) -> Self

Return the vector with the x-value replaced.

pub fn with_y(self, y: T) -> Self

Return the vector with the y-value replaced.

pub fn with_z(self, z: T) -> Self

Return the vector with the z-value replaced.

pub fn with_w(self, w: T) -> Self

Return the vector with the w-value replaced.

Source

impl<T: Copy> Vec4<T>

pub const fn xy(self) -> Vec2<T>

Reduce to a 2D vector by dropping z and w.

pub const fn xyz(self) -> Vec3<T>

Reduce to a 3D vector by dropping w.

pub fn yxzw(self) -> Self

Swizzle components.

pub fn zxyw(self) -> Self

Swizzle components.

pub fn wxzy(self) -> Self

Swizzle components.

pub fn yxwz(self) -> Self

Swizzle components.

pub fn yzxw(self) -> Self

Swizzle components.

pub fn zyxw(self) -> Self

Swizzle components.

pub fn wzxy(self) -> Self

Swizzle components.

pub fn yzwx(self) -> Self

Swizzle components.

pub fn zywx(self) -> Self

Swizzle components.

pub fn wzyx(self) -> Self

Swizzle components.

pub fn ywzx(self) -> Self

Swizzle components.

Source

impl<T: Num> Vec4<T>

pub const X_AXIS: Self

A unit vector representing the x-axis, equal to (1, 0, 0, 0).

pub const Y_AXIS: Self

A unit vector representing the y-axis, equal to (0, 1, 0, 0).

pub const Z_AXIS: Self

A unit vector representing the z-axis, equal to (0, 0, 1, 0).

pub const W_AXIS: Self

A unit vector representing the w-axis, equal to (0, 0, 0, 1).