#[repr(C)]pub struct Line<T> {
pub start: Vec2<T>,
pub end: Vec2<T>,
}Expand description
A line segment connecting two points.
Fields
start: Vec2<T>The start point.
end: Vec2<T>The end point.
Implementations
Sourceimpl<T: Copy + AbsDiffEq<Epsilon = T>> Line<T>
impl<T: Copy + AbsDiffEq<Epsilon = T>> Line<T>
Sourcepub fn abs_diff_eq(&self, other: &Self) -> bool
pub fn abs_diff_eq(&self, other: &Self) -> bool
Returns true if the two values are approximately equal according to the absolute difference between their components.
Sourceimpl<T: Copy + RelativeEq<Epsilon = T>> Line<T>
impl<T: Copy + RelativeEq<Epsilon = T>> Line<T>
Sourcepub fn relative_eq(&self, other: &Self) -> bool
pub fn relative_eq(&self, other: &Self) -> bool
Returns true if the two values are approximately equal according to the absolute difference between their components, as well as relative-based comparisons.
Sourceimpl<T: Float> Line<T>
impl<T: Float> Line<T>
Sourcepub fn right_norm(&self) -> Vec2<T>
pub fn right_norm(&self) -> Vec2<T>
Right-perpendicular axis of the line.
Sourcepub fn project_onto_axis(&self, axis: Vec2<T>) -> Projection<T>
pub fn project_onto_axis(&self, axis: Vec2<T>) -> Projection<T>
Project this line onto the provided axis.
Sourcepub fn project_point(&self, p: Vec2<T>) -> Vec2<T>
pub fn project_point(&self, p: Vec2<T>) -> Vec2<T>
Project the point onto this line.
Sourcepub fn raycast(&self, ray: &Ray<T>) -> Option<T>
pub fn raycast(&self, ray: &Ray<T>) -> Option<T>
Cast a ray against this line. If it intersects the line, return the distance along the ray that the intersection occurred.
pub fn transform_by(&self, f: impl FnMut(Vec2<T>) -> Vec2<T>) -> Self