#[repr(C)]pub struct Projection<T> {
pub min: T,
pub max: T,
}Expand description
Represents the projection of a 2D shape on an axis.
This primitive does not contain the axis itself, merely the start and end bounds of the projection. This is used in overlap checks for convex shapes.
Fields
min: Tmax: TImplementations
Sourceimpl<T: Pod + NoUninit> Projection<T>
impl<T: Pod + NoUninit> Projection<T>
Sourceimpl<T: Copy + AbsDiffEq<Epsilon = T>> Projection<T>
impl<T: Copy + AbsDiffEq<Epsilon = T>> Projection<T>
Sourcepub fn abs_diff_eq(&self, other: &Self) -> bool
pub fn abs_diff_eq(&self, other: &Self) -> bool
Returns true if the two values are approximately equal according to the absolute difference between their components.
Sourceimpl<T: Copy + RelativeEq<Epsilon = T>> Projection<T>
impl<T: Copy + RelativeEq<Epsilon = T>> Projection<T>
Sourcepub fn relative_eq(&self, other: &Self) -> bool
pub fn relative_eq(&self, other: &Self) -> bool
Returns true if the two values are approximately equal according to the absolute difference between their components, as well as relative-based comparisons.
Sourceimpl<T: Copy + UlpsEq<Epsilon = T>> Projection<T>
impl<T: Copy + UlpsEq<Epsilon = T>> Projection<T>
Sourceimpl<T> Projection<T>
impl<T> Projection<T>
Sourceimpl<T: Num> Projection<T>
impl<T: Num> Projection<T>