#[repr(C)]pub struct RayHit<T> {
pub normal: Vec2<T>,
pub distance: T,
}Expand description
A raycast hit on the surface of a shape.
Contains the distance along the ray the hit occurred, and the
normal of the edge the ray intersected.
Fields
normal: Vec2<T>distance: TImplementations
Sourceimpl<T: Copy + AbsDiffEq<Epsilon = T>> RayHit<T>
impl<T: Copy + AbsDiffEq<Epsilon = T>> RayHit<T>
Sourcepub fn abs_diff_eq(&self, other: &Self) -> bool
pub fn abs_diff_eq(&self, other: &Self) -> bool
Returns true if the two values are approximately equal according to the absolute difference between their components.
Sourceimpl<T: Copy + RelativeEq<Epsilon = T>> RayHit<T>
impl<T: Copy + RelativeEq<Epsilon = T>> RayHit<T>
Sourcepub fn relative_eq(&self, other: &Self) -> bool
pub fn relative_eq(&self, other: &Self) -> bool
Returns true if the two values are approximately equal according to the absolute difference between their components, as well as relative-based comparisons.