#[repr(C)]pub struct Vec4<T> {
pub x: T,
pub y: T,
pub z: T,
pub w: T,
}Expand description
A 4-dimensional vector.
Fields
x: Ty: Tz: Tw: TImplementations
Sourceimpl<T> Vec4<T>
impl<T> Vec4<T>
Sourcepub fn splat(value: T) -> Selfwhere
T: Copy,
pub fn splat(value: T) -> Selfwhere
T: Copy,
Create a new vector with all components set to value.
Sourcepub fn abs(self) -> Selfwhere
T: Signed,
pub fn abs(self) -> Selfwhere
T: Signed,
Returns a copy of this vector with absolute value of all components.
Sourcepub fn signum(self) -> Selfwhere
T: Signed,
pub fn signum(self) -> Selfwhere
T: Signed,
Returns a copy of this vector with signed value of all components.
Sourcepub fn min(self, rhs: Self) -> Selfwhere
T: Num,
pub fn min(self, rhs: Self) -> Selfwhere
T: Num,
Returns a new value where each component is set to the smallest value of each of the supplied vector’s corresponding components.
Sourcepub fn max(self, rhs: Self) -> Selfwhere
T: Num,
pub fn max(self, rhs: Self) -> Selfwhere
T: Num,
Returns a new value where each component is set to the greatest value of each of the supplied vector’s corresponding components.
Sourcepub fn clamp(self, min: Self, max: Self) -> Selfwhere
T: Num,
pub fn clamp(self, min: Self, max: Self) -> Selfwhere
T: Num,
Clamps the vector’s components within the provided bounds.
Sourcepub fn trunc(self) -> Selfwhere
T: Float,
pub fn trunc(self) -> Selfwhere
T: Float,
Truncates the components of this vector. This means that non-integer numbers are always truncated towards zero.
Sourcepub fn sqr_dist(self, other: Self) -> Twhere
T: Num,
pub fn sqr_dist(self, other: Self) -> Twhere
T: Num,
The square distance between this vector and another.
Sourcepub fn reflect(self, normal: Self) -> Selfwhere
T: Num,
pub fn reflect(self, normal: Self) -> Selfwhere
T: Num,
Reflects this vector off the provided normal.
Sourcepub fn dist(self, other: Self) -> Twhere
T: Float,
pub fn dist(self, other: Self) -> Twhere
T: Float,
The distance between this vector and another.
Sourcepub fn norm_safe(self) -> Selfwhere
T: Float,
pub fn norm_safe(self) -> Selfwhere
T: Float,
Returns a normalized version of this vector, or a zeroed vector if the vector cannot be normalized.
Sourcepub fn len_to(self, new_len: T) -> Selfwhere
T: Float,
pub fn len_to(self, new_len: T) -> Selfwhere
T: Float,
Returns a copy of this vector resized to be the provided length.
Sourcepub fn len_to_safe(self, new_len: T) -> Selfwhere
T: Float,
pub fn len_to_safe(self, new_len: T) -> Selfwhere
T: Float,
Returns a copy of this vector resized to be the provided length, or a zeroed vector if the original could not be normalized.
Sourceimpl<T: Copy + AbsDiffEq<Epsilon = T>> Vec4<T>
impl<T: Copy + AbsDiffEq<Epsilon = T>> Vec4<T>
Sourcepub fn abs_diff_eq(&self, other: &Self) -> bool
pub fn abs_diff_eq(&self, other: &Self) -> bool
Returns true if the two values are approximately equal according to the absolute difference between their components.
Sourceimpl<T: Copy + RelativeEq<Epsilon = T>> Vec4<T>
impl<T: Copy + RelativeEq<Epsilon = T>> Vec4<T>
Sourcepub fn relative_eq(&self, other: &Self) -> bool
pub fn relative_eq(&self, other: &Self) -> bool
Returns true if the two values are approximately equal according to the absolute difference between their components, as well as relative-based comparisons.